package trismegistoplanilla.mysqldao;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import org.json.JSONArray;
import org.json.JSONObject;
import trismegistoplanilla.beans.ParentescoBean;
import trismegistoplanilla.dao.ParentescoDAO;
import trismegistoplanilla.utilities.ResponseHelper;
import trismegistoplanilla.utilities.Variables;

public class ParentescoMysqlDAO implements ParentescoDAO {

	@Override
	public JSONObject listarParentesco() {
		System.out.println("ParentescoMysqlDAO: listarParentesco");
		JSONObject jsonListarParentesco = null;
		JSONArray jsonArrayListarParentesco = new JSONArray();
		PreparedStatement ps = null;
		ResultSet rs = null;
		Connection connection = null;

		ResponseHelper response = new ResponseHelper();

		try {
			connection = MysqlDAOFactory.obtenerConexion(Variables.MYSQL_NUEVO_BD_NAME);
			String sql
				= "select "
				+ "codigo_parentesco codigoParentesco, "
				+ "nombre nombre, "
				+ "estado_registro estadoRegistro "
				+ "FROM parentesco "
				+ "where estado_registro = 1";
			ps = connection.prepareStatement(sql);
			rs = ps.executeQuery();
			while (rs.next()) {
				ParentescoBean parentesco = new ParentescoBean();
				parentesco.setCodigoParentesco(rs.getInt("codigoParentesco"));
				parentesco.setNombre(rs.getString("nombre"));
				parentesco.setEstado_registro(rs.getInt("estadoRegistro"));
				JSONObject jsonObjParentesco = new JSONObject(parentesco);
				jsonArrayListarParentesco.put(jsonObjParentesco);
			}
			JSONObject jsonObjParentesco = new JSONObject();
			jsonObjParentesco.put("parentescos", jsonArrayListarParentesco);
			response.setStatus(true);
			response.setMessage("Los parentescos se han listado correctamente");
			response.setData(jsonObjParentesco);

		} catch (SQLException e) {
			e.printStackTrace();
			response.setStatus(false);
			response.setMessage("Error: " + e.getMessage() + " \n Error Code: [" + e.getErrorCode() + "]");
		} finally {
			try {
				if (rs != null) {
					rs.close();
				}
				if (ps != null) {
					ps.close();
				}
				if (connection != null) {
					connection.close();
				}
			} catch (SQLException e) {
				e.printStackTrace();
			}
		}

		jsonListarParentesco = new JSONObject(response);
		return jsonListarParentesco;
	}

	@Override
	public JSONObject validarExistenciaParentesco(ParentescoBean parentesco) {
		System.out.println("ParentescoMysqlDAO: validarExistenciaParentesco");
		JSONObject jsonValidarExistenciaParentesco = null;
		ResponseHelper response = new ResponseHelper();
		int existeParentesco = 0;

		Connection connection = null;
		PreparedStatement ps = null;
		ResultSet rs = null;
		try {
			connection = MysqlDAOFactory.obtenerConexion(Variables.MYSQL_NUEVO_BD_NAME);
			String sql
				= "select "
				+ "count(1) as existeParentesco "
				+ "from parentesco "
				+ "where codigo_parentesco = ? and estado_registro = 1";
			ps = connection.prepareStatement(sql);
			ps.setInt(1, parentesco.getCodigoParentesco());
			rs = ps.executeQuery();
			rs.next();
			existeParentesco = rs.getInt("existeParentesco");
			if (existeParentesco > 0) {
				response.setStatus(true);
				response.setMessage("El parentesco seleccionado existe.");
			} else {
				response.setStatus(false);
				response.setMessage("El parentesco seleccionado no existe.");
			}
		} catch (SQLException e) {
			e.printStackTrace();
			response.setStatus(false);
			response.setMessage("Error: " + e.getMessage() + " \n Error Code: [" + e.getErrorCode() + "]");
		} finally {
			try {
				if (rs != null) {
					rs.close();
				}
				if (ps != null) {
					ps.close();
				}
				if (connection != null) {
					connection.close();
				}
			} catch (SQLException e) {
				e.printStackTrace();
			}
		}
		jsonValidarExistenciaParentesco = new JSONObject(response);
		return jsonValidarExistenciaParentesco;
	}

}
