let globalListado = {
  TIPO_DOCUMENTO: {
    codigoCriterio: 1,
    codigoTipoDocumento: 0,
    tipoEntrada: "",
    longitud: 0,
    numeroDocumento: ""
  },
  APELLIDOS: {
    codigoCriterio: 2,
    apellidos: ""
  },
  FECHA_REGISTRO: {
    codigoCriterio: 3,
    fechaRegistro: ""
  }
}

/**
 * Crea los elementos option del array que se pase como parametro
 * @method createSelectOptions
 * @param {JSONArray} obj array de objetos
 * @param {String} valueName la key del json que se usará como value del elemento option
 * @param {String} textName la key del json que se usará como text del elemento option
 * @returns {Promise} Promise retorna status, msg
 */
let createSelectOptions = (obj, valueName, textName) => {
  let options = '<option value="0">[SELECCIONAR]</option>';
  obj.forEach((data) => {
    options += '<option value="' + data[valueName] + '">' + data[textName] + '</option>';
  });
  return options;
};

const configPanel = {
  criterioChange() {
    getNode('#cboCriterioBusqueda').onchange = (e) => {
      $('#divRowFiltro1').html('');
      $('#divRowFiltro2').html('');
      if (!isNaN(e.currentTarget.value)) {
        switch (parseInt(e.currentTarget.value)) {
          case 1: // tipo documento
            this.pintarTipoDocumento();
            break;
          case 2: // apellidos
            this.pintarApellidos();
            break;
          case 3: // fecha de registro
            this.pintarFechaRegistro();
            break;
          default:
            $('#divRowFiltro1').html('');
            $('#divRowFiltro2').html('');
            break;
        }
        $(e.currentTarget).valid();
      }
    }
  },

  pintarTipoDocumento() {
    request.listarTipoDocumento().then((array) => {
      let tipoDocumento = `
      <div class="col-md-4">
          <div class="form-group">
            <label for="cboTipoDocumento" class="text-semibold">Tipo documento <span class="text-danger">*</span></label>
            <select class="select" id="cboTipoDocumento" name="cboTipoDocumento">
            ${createSelectOptions(array, 'codigoTipoDocumento', 'descripcionCorta')}
            </select>
          </div>
      </div>`;
      $('#divRowFiltro1').html(tipoDocumento);
      incializeComponents.select2ById('cboTipoDocumento');
      this.pintarNumeroDocumento(array);
      validForm.reglas();
    });
  },

  pintarApellidos() {
    let txtApellidos = `
      <div class="col-md-4">
          <div class="form-group">
              <label for="txtApellidos" class="text-semibold">Apellido paterno <span class="text-danger">*</span></label>
              <input type="text" class="form-control text-uppercase" placeholder="Ingresar apellido paterno" id="txtApellidos" name="txtApellidos" maxlength="30" autocomplete="off" required>
          </div>
      </div>`;
    $('#divRowFiltro1').html(txtApellidos);
    $('#txtApellidos').validCampo('abcdefghijklmnñopqrstuvwxyzáéíóú ');
    validForm.reglas();
  },

  pintarFechaRegistro() {
    let dpFechaRegistro = `
    <div class="col-md-4">
        <label for="dpFechaRegistro" class="text-semibold">Fecha de registro <span class="text-danger">*</span></label>
        <div class="input-group">
            <span class="input-group-addon"><i class="icon-calendar"></i></span>
            <input type="text" class="form-control datepicker" placeholder="Fecha de registro de ficha" id="dpFechaRegistro" name="dpFechaRegistro" autocomplete="off">
        </div>        
    </div>`;
    $('#divRowFiltro1').html(dpFechaRegistro);
    incializeComponents.selectDatePicker();
    validForm.reglas();
  },

  pintarNumeroDocumento(array) {
    getNode('#cboTipoDocumento').onchange = (e) => {
      if (!isNaN(e.currentTarget.value)) {
        if (parseInt(e.currentTarget.value) !== 0) {
          array.map((data) => {
            if (parseInt(e.currentTarget.value) === data.codigoTipoDocumento) {
              let txtNumeroDocumento = `
              <div class="col-md-4">
                  <div class="form-group">
                      <label for="txtNumeroDocumento" class="text-semibold">N° Documento <span class="text-danger">*</span></label>
                      <input type="text" class="form-control text-uppercase" placeholder="Ingresar nro documento" id="txtNumeroDocumento" name="txtNumeroDocumento" minlength="${data.longitud}" maxlength="${data.longitud}" autocomplete="off" required>            
                  </div>
              </div>`;
              $('#divRowFiltro2').html(txtNumeroDocumento);
              globalListado.TIPO_DOCUMENTO.codigoTipoDocumento = parseInt(e.currentTarget.value);
              globalListado.TIPO_DOCUMENTO.tipoEntrada = data.tipoEntrada;
              globalListado.TIPO_DOCUMENTO.longitud = data.longitud;
            }
          });
        } else {
          $('#divRowFiltro2').html('');
        }
      }
      validForm.reglas();
      $(e.currentTarget).valid();
    }
  },

  limpiarFiltro() {
    Ladda.bind('#btnLimpiarFiltroFichaPendiente', {
      callback: function (instance) {
        let progress = 0;
        let interval = setInterval(function () {
          progress = Math.min(progress + Math.random(), 100);
          instance.setProgress(progress);
          if (progress === 100) {
            instance.stop();
            clearInterval(interval);
            $('#divRowFiltro1').html('');
            $('#divRowFiltro2').html('');
            $('#cboCriterioBusqueda').val(0).trigger('change');
            let formBusquedaFichaPendiente = $('#formBusquedaFichaPendiente').validate();
            formBusquedaFichaPendiente.resetForm();
            accionBuscar.buscarFichasPendientes();
          }
        });
      }
    });
  }
}

const validForm = {
  reglas() {
    // select criterio
    $(getNode('#cboCriterioBusqueda')).rules('add', {
      valueNotEquals: '0'
    });

    // select tipo documento
    $(getNode('#cboTipoDocumento')).rules('add', {
      valueNotEquals: '0'
    });

    // input numero documento
    if (globalListado.TIPO_DOCUMENTO.tipoEntrada === 'N') {
      $('#txtNumeroDocumento').rules('remove', 'alphanumeric');
      $(getNode('#txtNumeroDocumento')).rules('add', {
        number: true
      });
      $('#txtNumeroDocumento').validCampo('1234567890');
    } else if (globalListado.TIPO_DOCUMENTO.tipoEntrada === 'A') {
      $('#txtNumeroDocumento').rules('remove', 'number');
      $(getNode('#txtNumeroDocumento')).rules('add', {
        alphanumeric: true
      });
      $('#txtNumeroDocumento').validCampo('1234567890abcdefghijklmnopqrstuvwxyz');
    }

    // input apellidos
    $(getNode('#txtApellidos')).rules('add', {
      required: true,
      lettersonly: true
    });

    // input fecha registro
    $(getNode('#dpFechaRegistro')).rules('add', {
      required: true,
      dateonly: true
    });
  },

  validarFormulario() {
    $(getNode('#formBusquedaFichaPendiente')).validate({
      submitHandler: function (form) {
        accionBuscar.buscarFichasPendientes();
        return false;
      }
    });
  }
}

configPanel.criterioChange();
configPanel.limpiarFiltro();
validForm.validarFormulario();
validForm.reglas();
