/* global Ladda, Promise */

const helpers = {
  ajaxRequest(obj) {
    return $.ajax({
      url: obj.url,
      type: obj.type,
      dataType: obj.dataType,
      data: obj.body,
      beforeSend: (xhr, settings) => {
        load(obj.loadingMessage)
      }, success: (response, textStatus, jqXHR) => {
        unload()
        return Promise.resolve(response)
      }, error: (jqXHR, textStatus, errorThrown) => {
        return Promise.reject({
          status: textStatus,
          message: `Error making the request`,
          request: obj
        })
      }
    })
  }
}
const lotes = {
  listar() {
    defaultConfigDataTable()
    let search = document.querySelector('#txtNumeroLote').value
    return new Promise((resolve) => {
      $(document.querySelector('#tblLotes')).DataTable().destroy()
      $(document.querySelector('#tblLotes')).DataTable({
        processing: true,
        serverSide: true,
        ajax: {
          url: '../LoteFichaServlet',
          dataType: 'json',
          type: 'post',
          data: {
            accion: 'listarLoteDT',
            search: search
          }
        },
        columnDefs: [
          {targets: 0, orderable: false, className: 'text-center'}, // #
          {targets: 1, orderable: false, className: 'text-center'}, // num lote
          {targets: 2, orderable: false, className: 'text-center'}, // fecha registro
          {targets: 3, orderable: false, className: 'text-center'}, // tipo lote
          {targets: 4, orderable: false, className: 'text-center'}, // N° fichas
          {targets: 5, orderable: false, className: 'text-center'}, // estado Lote
          {targets: 6, orderable: false, className: 'text-center'} // acciones
        ],
        columns: [
          {
            data: 'item'
          },
          {
            data: 'numeroLote'
          },
          {
            data: 'fechaRegistro'
          },
          {
            data: "tipoLote",
            className: 'text-center',
            render: (data, type, row) => {
              return data === 'A' ? `<span class="label bg-primary">ADMINISTRATIVO</span>` : `<span class="label bg-success">DOCENTE</span>`
            }
          },
          {
            data: 'numeroFichas',
            render: function (data) {
              return `<span style="font-size:18px;" class="text-bold">${data}</span>`
            }
          },
          {
            data: 'estilo'
          },
          {
            data: null,
            render: function (data) {
              return `<ul class="icons-list">
                        <li class="text-orange">
                            <a href="#" onclick="javascript: return false" class="verDetalleLote" data-toggle="tooltip" data-placement="top" title="Ver detalle lote"><i style="font-size:22px;" class="fa fa-folder-open fa-lg"></i></a>
                        </li>
                      </ul>
                      `
            }
          }
        ],
        fnInitComplete: function (settings, data) {
          $('.verDetalleLote').tooltip({
            template: '<div class="tooltip"><div class="bg-slate-800"><div class="tooltip-arrow"></div><div class="tooltip-inner"></div></div></div>'
          })
          resolve(data)
        }
      })
    })
  }
}
const formValidation = {
  init() {
    this.rules()
    this.formChange()
  },
  rules() {
    $(document.querySelector('#txtNumeroLote')).rules('add', {
      required: true,
      number: true
    })
  },
  formChange() {
    document.querySelector('#formFiltroLotes').addEventListener('change', (e) => {
      $(e.currentTarget).valid()
    })
  }
}
const DOMComponents = {
  init() {
    this.initializePluginComponents()
    this.configComponents()
  },
  initializePluginComponents() {
    Ladda.bind('#btnLimpiarFiltroLotes', {
      callback: (instance) => {
        let progress = 0
        let interval = setInterval(() => {
          progress = Math.min(progress + Math.random(), 2)
          instance.setProgress(progress)
          if (progress === 2) {
            instance.stop()
            clearInterval(interval)
            document.querySelector('#txtNumeroLote').value = ''
            lotes.listar()
          }
        }, 200)
      }
    })
  },
  configComponents() {
    new Input({el: '#txtNumeroLote', param: 'numbers'}).validate()
  }
}
const DOMEvents = () => {
  $(document.querySelector('#formFiltroLotes')).validate({
    submitHandler: (form, e) => {
      lotes.listar()
      return false
    }
  })

  $('#tblLotes tbody').on('click', '.verDetalleLote', (e) => {
    let data = $(document.querySelector('#tblLotes')).DataTable().row($(e.currentTarget).parents('tr')).data()
    httpRequest.obtenerDetalleLote({id: data.codigoFichaLote, tipoLote: data.tipoLote})
      .then((obj) => {
        data.detalle = obj.data.fichas
        localStorage.setItem('lote', JSON.stringify(data))
        window.location = "detalleLoteDocente.jsp"
      })

  })
}
const httpRequest = {
  obtenerDetalleLote(obj) {
    let accion = ''
    if (obj.tipoLote === 'D') {
      accion = 'listarDetalleLoteFichaDocenteDT'
    } else if (obj.tipoLote === 'A') {
      accion = 'listarDetalleLoteFichaAdministrativoDT'
    } else {
      accion = ''
    }
    return helpers.ajaxRequest({
      url: '../DetalleLoteFichaDocenteServlet',
      dataType: 'json',
      type: 'POST',
      body: {
        codigoFichaLote: obj.id,
        accion: accion
      },
      loadingMessage: 'Obteniendo detalle'
    })
  }
}

lotes.listar()
DOMEvents()
DOMComponents.init()
formValidation.init()
removeLocal('lote')